# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/youssef/newcms/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/youssef/newcms/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Youssef\\Newcms\\": "packages/youssef/newcms/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Youssef\Newcms\Providers\NewcmsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Newcms'  => Youssef\Newcms\Facades\Newcms::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Youssef\\NewcmsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Youssef\Newcms\Providers\NewcmsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Youssef\Newcms\Providers\NewcmsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Youssef\Newcms\Providers\NewcmsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/newcms/{modulename}

**User**

    http://path-to-route-folder/user/newcms/{modulename}

**Public**

    http://path-to-route-folder/newcms


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/newcms/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/newcms/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/newcms/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/newcms/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/newcms/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/newcms/{modulename}/{slug}
    METHOD: GET