<?php

namespace Youssef\Newcms\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Youssef\Newcms\Http\Requests\PageRequest;
use Youssef\Newcms\Interfaces\PageRepositoryInterface;
use Youssef\Newcms\Models\Page;
use Youssef\Newcms\Forms\Page as Form;

/**
 * APIController  class for page.
 */
class PageAPIController extends BaseController
{

    /**
     * Initialize page resource controller.
     *
     * @param type PageRepositoryInterface $page
     *
     * @return null
     */
    public function __construct(PageRepositoryInterface $page)
    {
        parent::__construct();
        $this->repository = $page;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Youssef\Newcms\Repositories\Criteria\PageResourceCriteria::class);
    }

    /**
     * Display a list of page.
     *
     * @return Response
     */
    public function index(PageRequest $request)
    {
        return $this->repository
            ->setPresenter(\Youssef\Newcms\Repositories\Presenter\PagePresenter::class)
            ->paginate();
    }

    /**
     * Display page.
     *
     * @param Request $request
     * @param Model   $page
     *
     * @return Response
     */
    public function show(PageRequest $request, Page $page)
    {
        return $page->setPresenter(\Youssef\Newcms\Repositories\Presenter\PageListPresenter::class);
        ;
    }

    /**
     * Create new page.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PageRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('newcms::page.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('newcms/page/' . $page->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('newcms/page');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the page.
     *
     * @param Request $request
     * @param Model   $page
     *
     * @return Response
     */
    public function update(PageRequest $request, Page $page)
    {
        try {
            $data = $request->all();

            $page->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('newcms::page.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('newcms/page/' . $page->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('newcms/page/' . $page->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the page.
     *
     * @param Model   $page
     *
     * @return Response
     */
    public function destroy(PageRequest $request, Page $page)
    {
        try {
            $page->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('newcms::page.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('newcms/page/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('newcms/page/' . $page->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
