<?php

namespace Youssef\Newcms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Youssef\Newcms\Models\Page;

class PagePolicy
{

    /**
     * Determine if the given user can view the page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function view(UserPolicy $user, Page $page)
    {
        if ($user->canDo('newcms.page.view') && $user->isAdmin()) {
            return true;
        }

        return $page->user_id == user_id() && $page->user_type == user_type();
    }

    /**
     * Determine if the given user can create a page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('newcms.page.create');
    }

    /**
     * Determine if the given user can update the given page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function update(UserPolicy $user, Page $page)
    {
        if ($user->canDo('newcms.page.edit') && $user->isAdmin()) {
            return true;
        }

        return $page->user_id == user_id() && $page->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Page $page)
    {
        return $page->user_id == user_id() && $page->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Page $page)
    {
        if ($user->canDo('newcms.page.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given page.
     *
     * @param UserPolicy $user
     * @param Page $page
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Page $page)
    {
        if ($user->canDo('newcms.page.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
