<?php

namespace Youssef\Newcms\Providers;

use Illuminate\Support\ServiceProvider;

class NewcmsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'newcms');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'newcms');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerNewcms();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerNewcms()
    {
        $this->app->bind('newcms', function($app) {
            return new Newcms($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Newcms', 'Lavalite\Newcms\Facades\Newcms');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('youssef.newcms', function ($app) {
            return $this->app->make('Youssef\Newcms\Newcms');
        });

        // Bind Page to repository
        $this->app->bind(
            'Youssef\Newcms\Interfaces\PageRepositoryInterface',
            \Youssef\Newcms\Repositories\Eloquent\PageRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            'Youssef\Newcms\Interfaces\CategoryRepositoryInterface',
            \Youssef\Newcms\Repositories\Eloquent\CategoryRepository::class
        );

        $this->app->register(\Youssef\Newcms\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Youssef\Newcms\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and newcms's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'youssef.newcms'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeNewcms::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['youssef.newcms'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('youssef/newcms.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/newcms')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/newcms')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
